@@ -3,9 +3,9 @@ package com.sun.tools.javac.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "17.0.8.1+1" },
-            { "jdk", "17.0.8.1" },
-            { "release", "17.0.8.1" },
+            { "full", "23.0.1+11" },
+            { "jdk", "23.0.1" },
+            { "release", "23.0.1" },
         };
     }
 }
