@@ -722,14 +722,6 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
                "tidssone for Rocky Mountains (USA)",
                "MT",
             };
-        final String[] Mexico_Northwest = new String[] {
-               "normaltid for nordvestlege Mexico",
-               "",
-               "sommartid for nordvestlege Mexico",
-               "",
-               "tidssone for nordvestlege Mexico",
-               "",
-            };
         final String[] Australia_Central = new String[] {
                "sentralaustralsk standardtid",
                "ACST",
@@ -754,22 +746,6 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
                "vestaustralsk tid",
                "AWT",
             };
-        final String[] Greenland_Eastern = new String[] {
-               "austgr\u00f8nlandsk normaltid",
-               "",
-               "austgr\u00f8nlandsk sommartid",
-               "",
-               "austgr\u00f8nlandsk tid",
-               "",
-            };
-        final String[] Greenland_Western = new String[] {
-               "vestgr\u00f8nlandsk normaltid",
-               "",
-               "vestgr\u00f8nlandsk sommartid",
-               "",
-               "vestgr\u00f8nlandsk tid",
-               "",
-            };
         final String[] Indonesia_Eastern = new String[] {
                "austindonesisk tid",
                "WIT",
@@ -778,14 +754,6 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
                "",
                "WIT",
             };
-        final String[] Kazakhstan_Eastern = new String[] {
-               "austkasakhstansk tid",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Australia_CentralWestern = new String[] {
                "vest-sentralaustralsk standardtid",
                "",
@@ -812,8 +780,20 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "Europe/Bucharest", Europe_Eastern },
             { "Asia/Shanghai", China },
             { "UTC", EMPTY_ZONE },
+            { "GB",
+                new String[] {
+                    "",
+                    "GMT",
+                    "britisk sommartid",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "NZ", New_Zealand },
             { "ACT", Australia_Central },
             { "AET", Australia_Eastern },
+            { "AGT", Argentina },
             { "ART", Europe_Eastern },
             { "AST", Alaska },
             { "BET", Brasilia },
@@ -823,30 +803,74 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "CTT", China },
             { "EAT", Africa_Eastern },
             { "ECT", Europe_Central },
+            { "IET", America_Eastern },
             { "JST", Japan },
             { "MIT", Apia },
             { "NET", Armenia },
             { "NST", New_Zealand },
             { "PLT", Pakistan },
             { "PNT", America_Mountain },
+            { "PRC", China },
             { "PRT", Atlantic },
             { "PST", America_Pacific },
+            { "ROK", Korea },
+            { "Cuba", Cuba },
+            { "Eire",
+                new String[] {
+                    "",
+                    "GMT",
+                    "irsk sommartid",
+                    "IST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "Iran", Iran },
+            { "W-SU", Moscow },
+            { "Egypt", Europe_Eastern },
+            { "Japan", Japan },
+            { "Libya", Europe_Eastern },
+            { "Israel", Israel },
+            { "Navajo", America_Mountain },
+            { "Poland", Europe_Central },
             { "CST6CDT", America_Central },
             { "EST5EDT", America_Eastern },
+            { "GB-Eire",
+                new String[] {
+                    "",
+                    "GMT",
+                    "britisk sommartid",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
+            { "Jamaica", America_Eastern },
             { "MST7MDT", America_Mountain },
+            { "NZ-CHAT", Chatham },
             { "PST8PDT", America_Pacific },
+            { "Hongkong", Hong_Kong },
+            { "Portugal", Europe_Western },
+            { "US/Samoa", Samoa },
             { "Asia/Aden", Arabian },
             { "Asia/Baku", Azerbaijan },
             { "Asia/Dili", East_Timor },
             { "Asia/Gaza", Europe_Eastern },
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
+            { "US/Alaska", Alaska },
+            { "US/Hawaii", Hawaii_Aleutian },
             { "Asia/Chita", Yakutsk },
+            { "Asia/Dacca", Bangladesh },
             { "Asia/Dhaka", Bangladesh },
+            { "Asia/Macao", China },
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Asia/Almaty", Kazakhstan_Eastern },
+            { "US/Arizona", America_Mountain },
+            { "US/Central", America_Central },
+            { "US/Eastern", America_Eastern },
+            { "US/Pacific", America_Pacific },
             { "Asia/Beirut", Europe_Eastern },
             { "Asia/Harbin", China },
             { "Asia/Hebron", Europe_Eastern },
@@ -855,16 +879,24 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "Asia/Riyadh", Arabian },
             { "Asia/Taipei", Taipei },
             { "Asia/Tehran", Iran },
+            { "Asia/Yangon", Cocos },
+            { "Brazil/East", Brasilia },
+            { "Brazil/West", Amazon },
             { "Europe/Kiev", Europe_Eastern },
+            { "Europe/Kyiv", Europe_Eastern },
             { "Europe/Oslo", Europe_Central },
             { "Europe/Riga", Europe_Eastern },
             { "Europe/Rome", Europe_Central },
             { "Pacific/Yap", Truk },
+            { "US/Aleutian", Hawaii_Aleutian },
+            { "US/Michigan", America_Eastern },
+            { "US/Mountain", America_Mountain },
             { "Africa/Cairo", Europe_Eastern },
             { "Africa/Ceuta", Europe_Central },
             { "Africa/Lagos", Africa_Western },
             { "Africa/Tunis", Europe_Central },
             { "America/Adak", Hawaii_Aleutian },
+            { "America/Atka", Hawaii_Aleutian },
             { "America/Lima", Peru },
             { "America/Nome", Alaska },
             { "Asia/Baghdad", Arabian },
@@ -888,6 +920,7 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "SystemV/CST6", America_Central },
             { "SystemV/EST5", America_Eastern },
             { "SystemV/MST7", America_Mountain },
+            { "Africa/Asmara", Africa_Eastern },
             { "Africa/Asmera", Africa_Eastern },
             { "Africa/Bangui", Africa_Western },
             { "Africa/Douala", Africa_Western },
@@ -903,10 +936,13 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "Asia/Ashgabat", Turkmenistan },
             { "Asia/Jayapura", Indonesia_Eastern },
             { "Asia/Khandyga", Yakutsk },
-            { "Asia/Qostanay", Kazakhstan_Eastern },
             { "Asia/Sakhalin", Sakhalin },
             { "Asia/Tashkent", Uzbekistan },
+            { "Asia/Tel_Aviv", Israel },
             { "Asia/Ust-Nera", Vladivostok },
+            { "Australia/ACT", Australia_Eastern },
+            { "Australia/LHI", Lord_Howe },
+            { "Australia/NSW", Australia_Eastern },
             { "Europe/Athens", Europe_Eastern },
             { "Europe/Berlin", Europe_Central },
             { "Europe/Dublin",
@@ -919,6 +955,16 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
                     "GMT",
                 }
             },
+            { "Europe/Jersey",
+                new String[] {
+                    "",
+                    "GMT",
+                    "britisk sommartid",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Lisbon", Europe_Western },
             { "Europe/London",
                 new String[] {
@@ -942,6 +988,7 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "Europe/Zurich", Europe_Central },
             { "Indian/Comoro", Africa_Eastern },
             { "Pacific/Efate", Vanuatu },
+            { "Pacific/Samoa", Samoa },
             { "SystemV/HST10", Hawaii_Aleutian },
             { "Africa/Algiers", Europe_Central },
             { "Africa/Kampala", Africa_Eastern },
@@ -962,10 +1009,18 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "America/Panama", America_Eastern },
             { "America/Recife", Brasilia },
             { "America/Regina", America_Central },
+            { "America/Virgin", Atlantic },
+            { "Asia/Ashkhabad", Turkmenistan },
             { "Asia/Chongqing", China },
+            { "Asia/Chungking", China },
             { "Asia/Hong_Kong", Hong_Kong },
             { "Asia/Pyongyang", Korea },
             { "Asia/Samarkand", Uzbekistan },
+            { "Atlantic/Faroe", Europe_Western },
+            { "Australia/West", Australia_Western },
+            { "Canada/Central", America_Central },
+            { "Canada/Eastern", America_Eastern },
+            { "Canada/Pacific", America_Pacific },
             { "Europe/Andorra", Europe_Central },
             { "Europe/Belfast",
                 new String[] {
@@ -977,15 +1032,19 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
                     "GMT",
                 }
             },
+            { "Europe/Nicosia", Europe_Eastern },
             { "Europe/Tallinn", Europe_Eastern },
             { "Europe/Vatican", Europe_Central },
             { "Europe/Vilnius", Europe_Eastern },
             { "Indian/Mayotte", Africa_Eastern },
+            { "Mexico/BajaSur", Mexico_Pacific },
+            { "Mexico/General", America_Central },
             { "Pacific/Easter", Easter },
+            { "Pacific/Kanton", Phoenix_Islands },
             { "Pacific/Midway", Samoa },
             { "Pacific/Noumea", New_Caledonia },
             { "Pacific/Tarawa", Gilbert_Islands },
-            { "Pacific/Wallis", Wallis },
+            { "Pacific/Wallis", Gilbert_Islands },
             { "Africa/Djibouti", Africa_Eastern },
             { "Africa/Kinshasa", Africa_Western },
             { "Africa/Ndjamena", Africa_Western },
@@ -994,10 +1053,10 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "America/Creston", America_Mountain },
             { "America/Curacao", Atlantic },
             { "America/Detroit", America_Eastern },
-            { "America/Godthab", Greenland_Western },
             { "America/Grenada", Atlantic },
             { "America/Iqaluit", America_Eastern },
             { "America/Jamaica", America_Eastern },
+            { "America/Knox_IN", America_Central },
             { "America/Managua", America_Central },
             { "America/Marigot", Atlantic },
             { "America/Mendoza", Argentina },
@@ -1010,19 +1069,36 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "America/Tortola", Atlantic },
             { "America/Yakutat", Alaska },
             { "Asia/Choibalsan", Mongolia },
+            { "Asia/Ulan_Bator", Mongolia },
             { "Atlantic/Azores", Azores },
             { "Atlantic/Canary", Europe_Western },
             { "Atlantic/Faeroe", Europe_Western },
             { "Australia/Eucla", Australia_CentralWestern },
+            { "Australia/North", Australia_Central },
             { "Australia/Perth", Australia_Western },
+            { "Australia/South", Australia_Central },
+            { "Canada/Atlantic", Atlantic },
+            { "Canada/Mountain", America_Mountain },
             { "Europe/Belgrade", Europe_Central },
             { "Europe/Brussels", Europe_Central },
             { "Europe/Budapest", Europe_Central },
             { "Europe/Busingen", Europe_Central },
             { "Europe/Chisinau", Europe_Eastern },
+            { "Europe/Guernsey",
+                new String[] {
+                    "",
+                    "GMT",
+                    "britisk sommartid",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Helsinki", Europe_Eastern },
             { "Europe/Sarajevo", Europe_Central },
+            { "Europe/Tiraspol", Europe_Eastern },
             { "Europe/Uzhgorod", Europe_Eastern },
+            { "Indian/Maldives", French_Southern },
             { "Pacific/Chatham", Chatham },
             { "Pacific/Norfolk", Norfolk },
             { "SystemV/AST4ADT", Atlantic },
@@ -1034,9 +1110,11 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "Africa/Mogadishu", Africa_Eastern },
             { "America/Anguilla", Atlantic },
             { "America/Asuncion", Paraguay },
+            { "America/Atikokan", America_Eastern },
             { "America/Barbados", Atlantic },
             { "America/Dominica", Atlantic },
             { "America/Edmonton", America_Mountain },
+            { "America/Ensenada", America_Pacific },
             { "America/Mazatlan", Mexico_Pacific },
             { "America/Miquelon", Pierre_Miquelon },
             { "America/Montreal", America_Eastern },
@@ -1047,6 +1125,7 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
+            { "Antarctica/Casey", Australia_Western },
             { "Asia/Krasnoyarsk", Krasnoyarsk },
             { "Asia/Novosibirsk", Novosibirsk },
             { "Asia/Ulaanbaatar", Mongolia },
@@ -1058,6 +1137,7 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "Australia/Darwin", Australia_Central },
             { "Australia/Hobart", Australia_Eastern },
             { "Australia/Sydney", Australia_Eastern },
+            { "Brazil/DeNoronha", Noronha },
             { "Europe/Amsterdam", Europe_Central },
             { "Europe/Gibraltar", Europe_Central },
             { "Europe/Ljubljana", Europe_Central },
@@ -1067,6 +1147,7 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "Europe/Volgograd", Volgograd },
             { "Indian/Kerguelen", French_Southern },
             { "Indian/Mauritius", Mauritius },
+            { "Mexico/BajaNorte", America_Pacific },
             { "Pacific/Auckland", New_Zealand },
             { "Pacific/Johnston", Hawaii_Aleutian },
             { "Africa/Libreville", Africa_Western },
@@ -1086,6 +1167,7 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "America/St_Thomas", Atlantic },
             { "America/Vancouver", America_Pacific },
             { "Asia/Novokuznetsk", Krasnoyarsk },
+            { "Chile/Continental", Chile },
             { "Europe/Bratislava", Europe_Central },
             { "Europe/Copenhagen", Europe_Central },
             { "Europe/Luxembourg", Europe_Central },
@@ -1098,6 +1180,7 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "Pacific/Pago_Pago", Samoa },
             { "Pacific/Rarotonga", Cook },
             { "Pacific/Tongatapu", Tonga },
+            { "US/Indiana-Starke", America_Central },
             { "Africa/Addis_Ababa", Africa_Eastern },
             { "Africa/Brazzaville", Africa_Western },
             { "America/Costa_Rica", America_Central },
@@ -1116,7 +1199,21 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "Atlantic/Jan_Mayen", Europe_Central },
             { "Australia/Adelaide", Australia_Central },
             { "Australia/Brisbane", Australia_Eastern },
+            { "Australia/Canberra", Australia_Eastern },
             { "Australia/Lindeman", Australia_Eastern },
+            { "Australia/Tasmania", Australia_Eastern },
+            { "Australia/Victoria", Australia_Eastern },
+            { "Chile/EasterIsland", Easter },
+            { "Europe/Isle_of_Man",
+                new String[] {
+                    "",
+                    "GMT",
+                    "britisk sommartid",
+                    "BST",
+                    "",
+                    "GMT",
+                }
+            },
             { "Europe/Kaliningrad", Europe_Eastern },
             { "Pacific/Kiritimati", Line_Islands },
             { "America/El_Salvador", America_Central },
@@ -1133,6 +1230,8 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "Atlantic/Cape_Verde", Cape_Verde },
             { "Australia/Lord_Howe", Lord_Howe },
             { "Australia/Melbourne", Australia_Eastern },
+            { "Canada/Newfoundland", Newfoundland },
+            { "Canada/Saskatchewan", America_Central },
             { "Indian/Antananarivo", Africa_Eastern },
             { "Africa/Dar_es_Salaam", Africa_Eastern },
             { "America/Blanc-Sablon", Atlantic },
@@ -1141,9 +1240,11 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "America/Dawson_Creek", America_Mountain },
             { "America/Indiana/Knox", America_Central },
             { "America/Rankin_Inlet", America_Central },
-            { "America/Santa_Isabel", Mexico_Northwest },
-            { "America/Scoresbysund", Greenland_Eastern },
+            { "America/Santa_Isabel", America_Pacific },
             { "Antarctica/Macquarie", Australia_Eastern },
+            { "Australia/Queensland", Australia_Eastern },
+            { "Australia/Yancowinna", Australia_Central },
+            { "Pacific/Port_Moresby", DumontDUrville },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
@@ -1157,9 +1258,12 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "Australia/Broken_Hill", Australia_Central },
             { "America/Bahia_Banderas", America_Central },
             { "America/Port-au-Prince", America_Eastern },
+            { "America/Argentina/Jujuy", Argentina },
             { "America/Argentina/Salta", Argentina },
             { "America/Indiana/Marengo", America_Eastern },
             { "America/Indiana/Winamac", America_Eastern },
+            { "America/Argentina/Cordoba", Argentina },
+            { "America/Argentina/Mendoza", Argentina },
             { "America/Argentina/Tucuman", Argentina },
             { "America/Argentina/Ushuaia", Argentina },
             { "America/Indiana/Tell_City", America_Central },
@@ -1170,15 +1274,19 @@ public class TimeZoneNames_nn extends TimeZoneNamesBundle {
             { "America/Argentina/San_Juan", Argentina },
             { "America/Argentina/San_Luis", Argentina },
             { "America/Indiana/Petersburg", America_Eastern },
+            { "America/Argentina/Catamarca", Argentina },
+            { "America/Kentucky/Louisville", America_Eastern },
             { "America/Kentucky/Monticello", America_Eastern },
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
             { "timezone.excity.Asia/Aqtobe", "Aktobe" },
             { "timezone.excity.Etc/Unknown", "ukjend by" },
+            { "America/Indiana/Indianapolis", America_Eastern },
             { "timezone.excity.Asia/Rangoon", "Yang\u00f4n" },
             { "timezone.excity.Indian/Cocos", "Kokos\u00f8yane" },
             { "timezone.excity.Asia/Ashgabat", "Asjgabat" },
             { "timezone.excity.Indian/Comoro", "Komorane" },
+            { "America/Argentina/Buenos_Aires", Argentina },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "America/North_Dakota/New_Salem", America_Central },
             { "timezone.excity.America/Cayman", "Cayman\u00f8yane" },
