@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -70,13 +66,13 @@ import sun.util.resources.TimeZoneNamesBundle;
 public class TimeZoneNames_tg extends TimeZoneNamesBundle {
     @Override
     protected final Object[][] getContents() {
-        final String[] Europe_Central = new String[] {
-               "\u0412\u0430\u049b\u0442\u0438 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u0438\u0438 \u0430\u0432\u0440\u0443\u043f\u043e\u0438\u0438 \u043c\u0430\u0440\u043a\u0430\u0437\u04e3",
+        final String[] GMT = new String[] {
+               "\u0412\u0430\u049b\u0442\u0438 \u043c\u0438\u0451\u043d\u0430\u0438 \u0413\u0440\u0438\u043d\u0432\u0438\u0447",
+               "GMT",
                "",
-               "\u0412\u0430\u049b\u0442\u0438 \u0442\u043e\u0431\u0438\u0441\u0442\u043e\u043d\u0430\u0438 \u0430\u0432\u0440\u0443\u043f\u043e\u0438\u0438 \u043c\u0430\u0440\u043a\u0430\u0437\u04e3",
-               "",
-               "\u0412\u0430\u049b\u0442\u0438 \u0430\u0432\u0440\u0443\u043f\u043e\u0438\u0438 \u043c\u0430\u0440\u043a\u0430\u0437\u04e3",
+               "BST",
                "",
+               "GMT",
             };
         final String[] ETC_UTC = new String[] {
                "\u0412\u0430\u049b\u0442\u0438 \u04b7\u0430\u04b3\u043e\u043d\u0438\u0438 \u04b3\u0430\u043c\u043e\u04b3\u0430\u043d\u0433\u0441\u043e\u0437\u04e3",
@@ -86,69 +82,69 @@ public class TimeZoneNames_tg extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] America_Eastern = new String[] {
-               "\u0412\u0430\u049b\u0442\u0438 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u0438\u0438 \u0448\u0430\u0440\u049b\u04e3",
-               "",
-               "\u0412\u0430\u049b\u0442\u0438 \u0440\u04ef\u0437\u043e\u043d\u0430\u0438 \u0448\u0430\u0440\u049b\u04e3",
-               "",
-               "\u0412\u0430\u049b\u0442\u0438 \u0448\u0430\u0440\u049b\u04e3",
-               "",
+        final String[] Atlantic = new String[] {
+               "\u0412\u0430\u049b\u0442\u0438 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u0438\u0438 \u0430\u0442\u043b\u0430\u043d\u0442\u0438\u043a\u04e3",
+               "AST",
+               "\u0412\u0430\u049b\u0442\u0438 \u0440\u04ef\u0437\u043e\u043d\u0430\u0438 \u0430\u0442\u043b\u0430\u043d\u0442\u0438\u043a\u04e3",
+               "AST",
+               "\u0412\u0430\u049b\u0442\u0438 \u0430\u0442\u043b\u0430\u043d\u0442\u0438\u043a\u04e3",
+               "AST",
             };
-        final String[] America_Pacific = new String[] {
-               "\u0412\u0430\u049b\u0442\u0438 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u0438\u0438 \u0423\u049b\u0451\u043d\u0443\u0441\u0438 \u041e\u0440\u043e\u043c",
-               "",
-               "\u0412\u0430\u049b\u0442\u0438 \u0440\u04ef\u0437\u043e\u043d\u0430\u0438 \u0423\u049b\u0451\u043d\u0443\u0441\u0438 \u041e\u0440\u043e\u043c",
-               "",
-               "\u0412\u0430\u049b\u0442\u0438 \u0423\u0451\u043d\u0443\u0441\u0438 \u041e\u0440\u043e\u043c",
-               "",
-            };
-        final String[] Europe_Western = new String[] {
-               "\u0412\u0430\u049b\u0442\u0438 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u0438\u0438 \u0430\u0432\u0440\u0443\u043f\u043e\u0438\u0438 \u0493\u0430\u0440\u0431\u04e3",
-               "",
-               "\u0412\u0430\u049b\u0442\u0438 \u0442\u043e\u0431\u0438\u0441\u0442\u043e\u043d\u0430\u0438 \u0430\u0432\u0440\u0443\u043f\u043e\u0438\u0438 \u0493\u0430\u0440\u0431\u04e3",
-               "",
-               "\u0412\u0430\u049b\u0442\u0438 \u0430\u0432\u0440\u0443\u043f\u043e\u0438\u0438 \u0493\u0430\u0440\u0431\u04e3",
-               "",
+        final String[] Europe_Central = new String[] {
+               "\u0412\u0430\u049b\u0442\u0438 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u0438\u0438 \u0430\u0432\u0440\u0443\u043f\u043e\u0438\u0438 \u043c\u0430\u0440\u043a\u0430\u0437\u04e3",
+               "CET",
+               "\u0412\u0430\u049b\u0442\u0438 \u0442\u043e\u0431\u0438\u0441\u0442\u043e\u043d\u0430\u0438 \u0430\u0432\u0440\u0443\u043f\u043e\u0438\u0438 \u043c\u0430\u0440\u043a\u0430\u0437\u04e3",
+               "CEST",
+               "\u0412\u0430\u049b\u0442\u0438 \u0430\u0432\u0440\u0443\u043f\u043e\u0438\u0438 \u043c\u0430\u0440\u043a\u0430\u0437\u04e3",
+               "CET",
             };
         final String[] Europe_Eastern = new String[] {
                "\u0412\u0430\u049b\u0442\u0438 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u0438\u0438 \u0430\u0432\u0440\u0443\u043f\u043e\u0438\u0438 \u0448\u0430\u0440\u049b\u04e3",
-               "",
+               "EET",
                "\u0412\u0430\u049b\u0442\u0438 \u0442\u043e\u0431\u0438\u0441\u0442\u043e\u043d\u0430\u0438 \u0430\u0432\u0440\u0443\u043f\u043e\u0438\u0438 \u0448\u0430\u0440\u049b\u04e3",
-               "",
+               "EEST",
                "\u0412\u0430\u049b\u0442\u0438 \u0430\u0432\u0440\u0443\u043f\u043e\u0438\u0438 \u0448\u0430\u0440\u049b\u04e3",
-               "",
+               "EET",
             };
-        final String[] Atlantic = new String[] {
-               "\u0412\u0430\u049b\u0442\u0438 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u0438\u0438 \u0430\u0442\u043b\u0430\u043d\u0442\u0438\u043a\u04e3",
-               "",
-               "\u0412\u0430\u049b\u0442\u0438 \u0440\u04ef\u0437\u043e\u043d\u0430\u0438 \u0430\u0442\u043b\u0430\u043d\u0442\u0438\u043a\u04e3",
-               "",
-               "\u0412\u0430\u049b\u0442\u0438 \u0430\u0442\u043b\u0430\u043d\u0442\u0438\u043a\u04e3",
-               "",
-            };
-        final String[] GMT = new String[] {
-               "\u0411\u0430 \u0432\u0430\u049b\u0442\u0438 \u0413\u0440\u0438\u043d\u0432\u0438\u0447",
-               "",
-               "",
-               "",
-               "",
-               "",
+        final String[] Europe_Western = new String[] {
+               "\u0412\u0430\u049b\u0442\u0438 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u0438\u0438 \u0430\u0432\u0440\u0443\u043f\u043e\u0438\u0438 \u0493\u0430\u0440\u0431\u04e3",
+               "WET",
+               "\u0412\u0430\u049b\u0442\u0438 \u0442\u043e\u0431\u0438\u0441\u0442\u043e\u043d\u0430\u0438 \u0430\u0432\u0440\u0443\u043f\u043e\u0438\u0438 \u0493\u0430\u0440\u0431\u04e3",
+               "WEST",
+               "\u0412\u0430\u049b\u0442\u0438 \u0430\u0432\u0440\u0443\u043f\u043e\u0438\u0438 \u0493\u0430\u0440\u0431\u04e3",
+               "WET",
             };
         final String[] America_Central = new String[] {
                "\u0412\u0430\u049b\u0442\u0438 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u0438\u0438 \u043c\u0430\u0440\u043a\u0430\u0437\u04e3",
-               "",
+               "CST",
                "\u0412\u0430\u049b\u0442\u0438 \u0440\u04ef\u0437\u043e\u043d\u0430\u0438 \u043c\u0430\u0440\u043a\u0430\u0437\u04e3",
-               "",
+               "CDT",
                "\u0412\u0430\u049b\u0442\u0438 \u043c\u0430\u0440\u043a\u0430\u0437\u04e3",
-               "",
+               "CT",
+            };
+        final String[] America_Eastern = new String[] {
+               "\u0412\u0430\u049b\u0442\u0438 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u0438\u0438 \u0448\u0430\u0440\u049b\u04e3",
+               "EST",
+               "\u0412\u0430\u049b\u0442\u0438 \u0440\u04ef\u0437\u043e\u043d\u0430\u0438 \u0448\u0430\u0440\u049b\u04e3",
+               "EST",
+               "\u0412\u0430\u049b\u0442\u0438 \u0448\u0430\u0440\u049b\u04e3",
+               "EST",
+            };
+        final String[] America_Pacific = new String[] {
+               "\u0412\u0430\u049b\u0442\u0438 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u0438\u0438 \u0423\u049b\u0451\u043d\u0443\u0441\u0438 \u041e\u0440\u043e\u043c",
+               "PST",
+               "\u0412\u0430\u049b\u0442\u0438 \u0440\u04ef\u0437\u043e\u043d\u0430\u0438 \u0423\u049b\u0451\u043d\u0443\u0441\u0438 \u041e\u0440\u043e\u043c",
+               "PDT",
+               "\u0412\u0430\u049b\u0442\u0438 \u0423\u049b\u0451\u043d\u0443\u0441\u0438 \u041e\u0440\u043e\u043c",
+               "PT",
             };
         final String[] America_Mountain = new String[] {
                "\u0412\u0430\u049b\u0442\u0438 \u0441\u0442\u0430\u043d\u0434\u0430\u0440\u0442\u0438\u0438 \u043a\u04ef\u04b3\u04e3",
-               "",
+               "MST",
                "\u0412\u0430\u049b\u0442\u0438 \u0440\u04ef\u0437\u043e\u043d\u0430\u0438 \u043a\u04ef\u04b3\u04e3",
-               "",
+               "MST",
                "\u0412\u0430\u049b\u0442\u0438 \u043a\u04ef\u04b3\u04e3",
-               "",
+               "MST",
             };
         final Object[][] data = new Object[][] {
             { "America/Los_Angeles", America_Pacific },
@@ -160,204 +156,302 @@ public class TimeZoneNames_tg extends TimeZoneNamesBundle {
             { "America/Halifax", Atlantic },
             { "Europe/Paris", Europe_Central },
             { "GMT", GMT },
-            { "Africa/Casablanca", Europe_Western },
             { "Europe/Bucharest", Europe_Eastern },
             { "UTC", ETC_UTC },
-            { "America/Marigot", Atlantic },
-            { "America/El_Salvador", America_Central },
-            { "America/Kentucky/Monticello", America_Eastern },
-            { "Africa/El_Aaiun", Europe_Western },
-            { "Africa/Ouagadougou", GMT },
-            { "America/Coral_Harbour", America_Eastern },
-            { "Africa/Cairo", Europe_Eastern },
-            { "America/Aruba", Atlantic },
-            { "America/North_Dakota/Center", America_Central },
-            { "America/Guatemala", America_Central },
-            { "PNT", America_Mountain },
-            { "Europe/London", GMT },
-            { "America/Cayman", America_Eastern },
-            { "America/Belize", America_Central },
-            { "America/Panama", America_Eastern },
-            { "Europe/San_Marino", Europe_Central },
-            { "America/Indiana/Tell_City", America_Central },
-            { "America/Tijuana", America_Pacific },
-            { "America/Managua", America_Central },
-            { "America/Indiana/Petersburg", America_Eastern },
-            { "Europe/Brussels", Europe_Central },
-            { "America/Chihuahua", America_Central },
-            { "America/Ojinaga", America_Central },
-            { "Europe/Warsaw", Europe_Central },
-            { "Europe/Jersey", GMT },
-            { "America/Tegucigalpa", America_Central },
-            { "Asia/Damascus", Europe_Eastern },
-            { "Europe/Luxembourg", Europe_Central },
+            { "GB", GMT },
             { "ART", Europe_Eastern },
-            { "Atlantic/Reykjavik", GMT },
-            { "Europe/Zaporozhye", Europe_Eastern },
-            { "Atlantic/St_Helena", GMT },
-            { "timezone.excity.Asia/Dushanbe", "\u0414\u0443\u0448\u0430\u043d\u0431\u0435" },
-            { "Europe/Guernsey", GMT },
-            { "Atlantic/Madeira", Europe_Western },
-            { "America/Thunder_Bay", America_Eastern },
-            { "America/Grand_Turk", America_Eastern },
-            { "Europe/Uzhgorod", Europe_Eastern },
-            { "America/Indiana/Marengo", America_Eastern },
-            { "America/Creston", America_Mountain },
-            { "Europe/Isle_of_Man", GMT },
-            { "America/Mexico_City", America_Central },
-            { "Africa/Tunis", Europe_Central },
-            { "Europe/Andorra", Europe_Central },
-            { "Africa/Tripoli", Europe_Eastern },
-            { "Africa/Banjul", GMT },
-            { "America/Matamoros", America_Central },
-            { "America/Blanc-Sablon", Atlantic },
-            { "Europe/Kaliningrad", Europe_Eastern },
-            { "Europe/Lisbon", Europe_Western },
-            { "PRT", Atlantic },
-            { "Europe/Oslo", Europe_Central },
-            { "Etc/GMT", GMT },
-            { "CST6CDT", America_Central },
-            { "Atlantic/Canary", Europe_Western },
-            { "Africa/Lome", GMT },
-            { "America/Menominee", America_Central },
-            { "Africa/Freetown", GMT },
-            { "Europe/Malta", Europe_Central },
-            { "America/Resolute", America_Central },
-            { "Europe/Busingen", Europe_Central },
-            { "PST", America_Pacific },
-            { "SystemV/EST5", America_Eastern },
-            { "Europe/Skopje", Europe_Central },
-            { "America/Edmonton", America_Mountain },
-            { "Europe/Podgorica", Europe_Central },
-            { "Europe/Sarajevo", Europe_Central },
-            { "America/Santo_Domingo", Atlantic },
-            { "America/Glace_Bay", Atlantic },
-            { "Europe/Kiev", Europe_Eastern },
-            { "Europe/Rome", Europe_Central },
-            { "America/Port-au-Prince", America_Eastern },
-            { "Europe/Belfast", GMT },
-            { "America/St_Barthelemy", Atlantic },
-            { "America/Nipigon", America_Eastern },
-            { "America/Regina", America_Central },
-            { "Atlantic/Jan_Mayen", Europe_Central },
-            { "America/Dawson_Creek", America_Mountain },
-            { "Africa/Algiers", Europe_Central },
-            { "Europe/Mariehamn", Europe_Eastern },
-            { "America/St_Thomas", Atlantic },
-            { "Europe/Zurich", Europe_Central },
-            { "America/Anguilla", Atlantic },
-            { "Europe/Vilnius", Europe_Eastern },
-            { "Africa/Bamako", GMT },
-            { "America/Cancun", America_Eastern },
-            { "Europe/Gibraltar", Europe_Central },
-            { "Africa/Conakry", GMT },
-            { "America/St_Lucia", Atlantic },
-            { "Europe/Madrid", Europe_Central },
-            { "America/Bahia_Banderas", America_Central },
-            { "America/Montserrat", Atlantic },
-            { "America/Cambridge_Bay", America_Mountain },
-            { "Europe/Vaduz", Europe_Central },
-            { "America/Barbados", Atlantic },
-            { "America/Louisville", America_Eastern },
-            { "America/Lower_Princes", Atlantic },
-            { "America/Vancouver", America_Pacific },
-            { "America/Danmarkshavn", GMT },
-            { "America/Detroit", America_Eastern },
-            { "Europe/Ljubljana", Europe_Central },
-            { "America/Thule", Atlantic },
-            { "America/Curacao", Atlantic },
-            { "America/Martinique", Atlantic },
-            { "Europe/Berlin", Europe_Central },
-            { "Europe/Chisinau", Europe_Eastern },
-            { "America/Puerto_Rico", Atlantic },
-            { "America/Rankin_Inlet", America_Central },
-            { "Europe/Stockholm", Europe_Central },
-            { "Africa/Dakar", GMT },
-            { "SystemV/CST6CDT", America_Central },
-            { "America/Tortola", Atlantic },
-            { "Europe/Budapest", Europe_Central },
-            { "Europe/Zagreb", Europe_Central },
-            { "America/Port_of_Spain", Atlantic },
-            { "Europe/Helsinki", Europe_Eastern },
-            { "Asia/Beirut", Europe_Eastern },
-            { "Europe/Tallinn", Europe_Eastern },
-            { "America/Rainy_River", America_Central },
-            { "Europe/Belgrade", Europe_Central },
-            { "Africa/Bissau", GMT },
-            { "SystemV/AST4", Atlantic },
-            { "America/Yellowknife", America_Mountain },
-            { "America/Indiana/Vevay", America_Eastern },
-            { "Africa/Ceuta", Europe_Central },
-            { "Africa/Timbuktu", GMT },
-            { "America/Goose_Bay", Atlantic },
-            { "America/Swift_Current", America_Central },
-            { "America/Pangnirtung", America_Eastern },
-            { "Europe/Sofia", Europe_Eastern },
-            { "Africa/Nouakchott", GMT },
-            { "Europe/Prague", Europe_Central },
-            { "America/Indiana/Vincennes", America_Eastern },
-            { "America/Whitehorse", America_Pacific },
-            { "America/Kralendijk", Atlantic },
-            { "Antarctica/Troll", GMT },
-            { "ECT", Europe_Central },
-            { "America/Antigua", Atlantic },
-            { "America/Montreal", America_Eastern },
-            { "America/Inuvik", America_Mountain },
-            { "America/Iqaluit", America_Eastern },
-            { "Asia/Nicosia", Europe_Eastern },
-            { "America/Moncton", Atlantic },
-            { "America/Indiana/Winamac", America_Eastern },
-            { "SystemV/MST7MDT", America_Mountain },
-            { "America/St_Vincent", Atlantic },
-            { "Asia/Gaza", Europe_Eastern },
-            { "PST8PDT", America_Pacific },
-            { "timezone.excity.Etc/Unknown", "\u0428\u0430\u04b3\u0440\u0438 \u043d\u043e\u043c\u0430\u044a\u043b\u0443\u043c" },
-            { "America/Grenada", Atlantic },
-            { "Atlantic/Faeroe", Europe_Western },
-            { "Europe/Bratislava", Europe_Central },
-            { "America/Ciudad_Juarez", America_Mountain },
-            { "Europe/Copenhagen", Europe_Central },
-            { "Europe/Vienna", Europe_Central },
-            { "America/Merida", America_Central },
-            { "Europe/Tirane", Europe_Central },
-            { "SystemV/MST7", America_Mountain },
-            { "America/St_Kitts", Atlantic },
-            { "Arctic/Longyearbyen", Europe_Central },
-            { "America/Fort_Nelson", America_Mountain },
-            { "Europe/Riga", Europe_Eastern },
-            { "America/Dominica", Atlantic },
-            { "America/Guadeloupe", Atlantic },
-            { "Asia/Hebron", Europe_Eastern },
-            { "SystemV/PST8PDT", America_Pacific },
-            { "Africa/Abidjan", GMT },
-            { "Africa/Monrovia", GMT },
-            { "America/Boise", America_Mountain },
-            { "EST5EDT", America_Eastern },
-            { "America/North_Dakota/New_Salem", America_Central },
-            { "Atlantic/Bermuda", Atlantic },
-            { "America/Costa_Rica", America_Central },
-            { "America/Dawson", America_Pacific },
-            { "America/Shiprock", America_Mountain },
-            { "America/Winnipeg", America_Central },
-            { "Europe/Amsterdam", Europe_Central },
-            { "America/Indiana/Knox", America_Central },
-            { "America/North_Dakota/Beulah", America_Central },
-            { "Europe/Vatican", Europe_Central },
-            { "Africa/Accra", GMT },
-            { "Asia/Amman", Europe_Eastern },
-            { "Etc/UTC", ETC_UTC },
-            { "SystemV/AST4ADT", Atlantic },
             { "CST", America_Central },
-            { "Europe/Dublin", GMT },
-            { "America/Toronto", America_Eastern },
+            { "ECT", Europe_Central },
+            { "IET", America_Eastern },
+            { "PNT", America_Mountain },
+            { "PRT", Atlantic },
+            { "PST", America_Pacific },
+            { "UCT",
+                new String[] {
+                    "\u0412\u0430\u049b\u0442\u0438 \u04b7\u0430\u04b3\u043e\u043d\u0438\u0438 \u04b3\u0430\u043c\u043e\u04b3\u0430\u043d\u0433\u0441\u043e\u0437\u04e3",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "Eire", GMT },
+            { "GMT0", GMT },
+            { "Zulu",
+                new String[] {
+                    "\u0412\u0430\u049b\u0442\u0438 \u04b7\u0430\u04b3\u043e\u043d\u0438\u0438 \u04b3\u0430\u043c\u043e\u04b3\u0430\u043d\u0433\u0441\u043e\u0437\u04e3",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "Egypt", Europe_Eastern },
+            { "Libya", Europe_Eastern },
+            { "Navajo", America_Mountain },
+            { "Poland", Europe_Central },
+            { "CST6CDT", America_Central },
+            { "EST5EDT", America_Eastern },
+            { "Etc/GMT", GMT },
+            { "Etc/UCT",
+                new String[] {
+                    "\u0412\u0430\u049b\u0442\u0438 \u04b7\u0430\u04b3\u043e\u043d\u0438\u0438 \u04b3\u0430\u043c\u043e\u04b3\u0430\u043d\u0433\u0441\u043e\u0437\u04e3",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "Etc/UTC", ETC_UTC },
+            { "GB-Eire", GMT },
+            { "Iceland", GMT },
+            { "Jamaica", America_Eastern },
             { "MST7MDT", America_Mountain },
-            { "America/Monterrey", America_Central },
-            { "SystemV/EST5EDT", America_Eastern },
-            { "America/Nassau", America_Eastern },
-            { "America/Jamaica", America_Eastern },
-            { "Europe/Athens", Europe_Eastern },
+            { "PST8PDT", America_Pacific },
+            { "Etc/GMT0", GMT },
+            { "Etc/Zulu",
+                new String[] {
+                    "\u0412\u0430\u049b\u0442\u0438 \u04b7\u0430\u04b3\u043e\u043d\u0438\u0438 \u04b3\u0430\u043c\u043e\u04b3\u0430\u043d\u0433\u0441\u043e\u0437\u04e3",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "Portugal", Europe_Western },
+            { "Asia/Gaza", Europe_Eastern },
+            { "Etc/GMT+0", GMT },
+            { "Etc/GMT-0", GMT },
+            { "Greenwich", GMT },
+            { "Universal",
+                new String[] {
+                    "\u0412\u0430\u049b\u0442\u0438 \u04b7\u0430\u04b3\u043e\u043d\u0438\u0438 \u04b3\u0430\u043c\u043e\u04b3\u0430\u043d\u0433\u0441\u043e\u0437\u04e3",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "US/Arizona", America_Mountain },
+            { "US/Central", America_Central },
+            { "US/Eastern", America_Eastern },
+            { "US/Pacific", America_Pacific },
+            { "Africa/Lome", GMT },
+            { "Asia/Beirut", Europe_Eastern },
+            { "Asia/Hebron", Europe_Eastern },
+            { "Europe/Kiev", Europe_Eastern },
+            { "Europe/Kyiv", Europe_Eastern },
+            { "Europe/Oslo", Europe_Central },
+            { "Europe/Riga", Europe_Eastern },
+            { "Europe/Rome", Europe_Central },
+            { "US/Michigan", America_Eastern },
+            { "US/Mountain", America_Mountain },
+            { "Africa/Accra", GMT },
+            { "Africa/Cairo", Europe_Eastern },
+            { "Africa/Ceuta", Europe_Central },
+            { "Africa/Dakar", GMT },
+            { "Africa/Tunis", Europe_Central },
+            { "Asia/Nicosia", Europe_Eastern },
+            { "Europe/Malta", Europe_Central },
+            { "Europe/Sofia", Europe_Eastern },
+            { "Europe/Vaduz", Europe_Central },
+            { "SystemV/AST4", Atlantic },
             { "SystemV/CST6", America_Central },
+            { "SystemV/EST5", America_Eastern },
+            { "SystemV/MST7", America_Mountain },
+            { "Africa/Bamako", GMT },
+            { "Africa/Banjul", GMT },
+            { "Africa/Bissau", GMT },
+            { "America/Aruba", Atlantic },
+            { "America/Boise", America_Mountain },
+            { "America/Thule", Atlantic },
+            { "Etc/Greenwich", GMT },
+            { "Etc/Universal",
+                new String[] {
+                    "\u0412\u0430\u049b\u0442\u0438 \u04b7\u0430\u04b3\u043e\u043d\u0438\u0438 \u04b3\u0430\u043c\u043e\u04b3\u0430\u043d\u0433\u0441\u043e\u0437\u04e3",
+                    "UTC",
+                    "",
+                    "UTC",
+                    "",
+                    "UTC",
+                }
+            },
+            { "Europe/Athens", Europe_Eastern },
+            { "Europe/Berlin", Europe_Central },
+            { "Europe/Dublin", GMT },
+            { "Europe/Jersey", GMT },
+            { "Europe/Lisbon", Europe_Western },
+            { "Europe/London", GMT },
+            { "Europe/Madrid", Europe_Central },
             { "Europe/Monaco", Europe_Central },
+            { "Europe/Prague", Europe_Central },
+            { "Europe/Skopje", Europe_Central },
+            { "Europe/Tirane", Europe_Central },
+            { "Europe/Vienna", Europe_Central },
+            { "Europe/Warsaw", Europe_Central },
+            { "Europe/Zagreb", Europe_Central },
+            { "Europe/Zurich", Europe_Central },
+            { "Africa/Abidjan", GMT },
+            { "Africa/Algiers", Europe_Central },
+            { "Africa/Conakry", GMT },
+            { "Africa/Tripoli", Europe_Eastern },
+            { "America/Belize", America_Central },
+            { "America/Cancun", America_Eastern },
+            { "America/Cayman", America_Eastern },
+            { "America/Inuvik", America_Mountain },
+            { "America/Merida", America_Central },
+            { "America/Nassau", America_Eastern },
+            { "America/Panama", America_Eastern },
+            { "America/Regina", America_Central },
+            { "America/Virgin", Atlantic },
+            { "Atlantic/Faroe", Europe_Western },
+            { "Canada/Central", America_Central },
+            { "Canada/Eastern", America_Eastern },
+            { "Canada/Pacific", America_Pacific },
+            { "Europe/Andorra", Europe_Central },
+            { "Europe/Belfast", GMT },
+            { "Europe/Nicosia", Europe_Eastern },
+            { "Europe/Tallinn", Europe_Eastern },
+            { "Europe/Vatican", Europe_Central },
+            { "Europe/Vilnius", Europe_Eastern },
+            { "Mexico/General", America_Central },
+            { "Africa/Freetown", GMT },
+            { "Africa/Monrovia", GMT },
+            { "Africa/Sao_Tome", GMT },
+            { "Africa/Timbuktu", GMT },
+            { "America/Antigua", Atlantic },
+            { "America/Creston", America_Mountain },
+            { "America/Curacao", Atlantic },
+            { "America/Detroit", America_Eastern },
+            { "America/Grenada", Atlantic },
+            { "America/Iqaluit", America_Eastern },
+            { "America/Jamaica", America_Eastern },
+            { "America/Knox_IN", America_Central },
+            { "America/Managua", America_Central },
+            { "America/Marigot", Atlantic },
+            { "America/Moncton", Atlantic },
+            { "America/Nipigon", America_Eastern },
+            { "America/Ojinaga", America_Central },
+            { "America/Tijuana", America_Pacific },
+            { "America/Toronto", America_Eastern },
+            { "America/Tortola", Atlantic },
+            { "Atlantic/Canary", Europe_Western },
+            { "Atlantic/Faeroe", Europe_Western },
+            { "Canada/Atlantic", Atlantic },
+            { "Canada/Mountain", America_Mountain },
+            { "Europe/Belgrade", Europe_Central },
+            { "Europe/Brussels", Europe_Central },
+            { "Europe/Budapest", Europe_Central },
+            { "Europe/Busingen", Europe_Central },
+            { "Europe/Chisinau", Europe_Eastern },
+            { "Europe/Guernsey", GMT },
+            { "Europe/Helsinki", Europe_Eastern },
+            { "Europe/Sarajevo", Europe_Central },
+            { "Europe/Tiraspol", Europe_Eastern },
+            { "Europe/Uzhgorod", Europe_Eastern },
+            { "SystemV/AST4ADT", Atlantic },
+            { "SystemV/CST6CDT", America_Central },
+            { "SystemV/EST5EDT", America_Eastern },
+            { "SystemV/MST7MDT", America_Mountain },
+            { "SystemV/PST8PDT", America_Pacific },
+            { "America/Anguilla", Atlantic },
+            { "America/Atikokan", America_Eastern },
+            { "America/Barbados", Atlantic },
+            { "America/Dominica", Atlantic },
+            { "America/Edmonton", America_Mountain },
+            { "America/Ensenada", America_Pacific },
+            { "America/Montreal", America_Eastern },
+            { "America/Resolute", America_Central },
+            { "America/Shiprock", America_Mountain },
+            { "America/St_Kitts", Atlantic },
+            { "America/St_Lucia", Atlantic },
+            { "America/Winnipeg", America_Central },
+            { "Antarctica/Troll", GMT },
+            { "Atlantic/Bermuda", Atlantic },
+            { "Atlantic/Madeira", Europe_Western },
+            { "Europe/Amsterdam", Europe_Central },
+            { "Europe/Gibraltar", Europe_Central },
+            { "Europe/Ljubljana", Europe_Central },
+            { "Europe/Mariehamn", Europe_Eastern },
+            { "Europe/Podgorica", Europe_Central },
+            { "Europe/Stockholm", Europe_Central },
+            { "Mexico/BajaNorte", America_Pacific },
+            { "Africa/Nouakchott", GMT },
+            { "America/Chihuahua", America_Central },
+            { "America/Glace_Bay", Atlantic },
+            { "America/Goose_Bay", Atlantic },
+            { "America/Guatemala", America_Central },
+            { "America/Matamoros", America_Central },
+            { "America/Menominee", America_Central },
+            { "America/Monterrey", America_Central },
+            { "America/St_Thomas", Atlantic },
+            { "America/Vancouver", America_Pacific },
+            { "Europe/Bratislava", Europe_Central },
+            { "Europe/Copenhagen", Europe_Central },
+            { "Europe/Luxembourg", Europe_Central },
+            { "Europe/San_Marino", Europe_Central },
+            { "Europe/Zaporozhye", Europe_Eastern },
+            { "US/Indiana-Starke", America_Central },
+            { "Africa/Ouagadougou", GMT },
+            { "America/Costa_Rica", America_Central },
+            { "America/Grand_Turk", America_Eastern },
+            { "America/Guadeloupe", Atlantic },
+            { "America/Kralendijk", Atlantic },
+            { "America/Louisville", America_Eastern },
+            { "America/Martinique", Atlantic },
+            { "America/Montserrat", Atlantic },
+            { "America/St_Vincent", Atlantic },
+            { "Atlantic/Jan_Mayen", Europe_Central },
+            { "Atlantic/Reykjavik", GMT },
+            { "Atlantic/St_Helena", GMT },
+            { "Europe/Isle_of_Man", GMT },
+            { "Europe/Kaliningrad", Europe_Eastern },
+            { "America/El_Salvador", America_Central },
+            { "America/Fort_Nelson", America_Mountain },
+            { "America/Mexico_City", America_Central },
+            { "America/Pangnirtung", America_Eastern },
+            { "America/Puerto_Rico", Atlantic },
+            { "America/Rainy_River", America_Central },
+            { "America/Tegucigalpa", America_Central },
+            { "America/Thunder_Bay", America_Eastern },
+            { "America/Yellowknife", America_Mountain },
+            { "Arctic/Longyearbyen", Europe_Central },
+            { "Canada/Saskatchewan", America_Central },
+            { "America/Blanc-Sablon", Atlantic },
+            { "America/Danmarkshavn", GMT },
+            { "America/Dawson_Creek", America_Mountain },
+            { "America/Indiana/Knox", America_Central },
+            { "America/Rankin_Inlet", America_Central },
+            { "America/Santa_Isabel", America_Pacific },
+            { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
+            { "America/Coral_Harbour", America_Eastern },
+            { "America/Indiana/Vevay", America_Eastern },
+            { "America/Lower_Princes", Atlantic },
+            { "America/Port_of_Spain", Atlantic },
+            { "America/Santo_Domingo", Atlantic },
+            { "America/St_Barthelemy", Atlantic },
+            { "America/Swift_Current", America_Central },
+            { "America/Bahia_Banderas", America_Central },
+            { "America/Port-au-Prince", America_Eastern },
+            { "America/Indiana/Marengo", America_Eastern },
+            { "America/Indiana/Winamac", America_Eastern },
+            { "America/Indiana/Tell_City", America_Central },
+            { "America/Indiana/Vincennes", America_Eastern },
+            { "America/Indiana/Petersburg", America_Eastern },
+            { "America/Kentucky/Louisville", America_Eastern },
+            { "America/Kentucky/Monticello", America_Eastern },
+            { "America/North_Dakota/Beulah", America_Central },
+            { "America/North_Dakota/Center", America_Central },
+            { "timezone.excity.Etc/Unknown", "\u0428\u0430\u04b3\u0440\u0438 \u043d\u043e\u043c\u0430\u044a\u043b\u0443\u043c" },
+            { "America/Indiana/Indianapolis", America_Eastern },
+            { "timezone.excity.Asia/Dushanbe", "\u0414\u0443\u0448\u0430\u043d\u0431\u0435" },
+            { "America/North_Dakota/New_Salem", America_Central },
         };
         return data;
     }
